==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>نمط المؤشر</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>نمط الموضة</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>وضع الكفاءة</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>الموقع</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>وضع</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>التطبيق على اليسار</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>التطبيق على القمة</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>التطبيق في المركز</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>قمة</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>ابقى مرئيًا</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>ابقى مخفيًا</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>إخفاء ذكي</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>إعدادات الدوكات</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>نمط المؤشر</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>نمط الموضة</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>وضع الكفاءة</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>ال新模式</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>الوضع المركزي</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>الموقع</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>وضع</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>قمة</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>ابقى مرئيًا</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>ابقى مخفيًا</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>إخفاء ذكي</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>إعدادات الدوكات</translation>
    </message>
</context>
</TS>
